ete2

Package ete2 |
[hide private]
[frames] | no frames]

# Package ete2

source code

Submodules | [hide private]
ete2.clustering ete2.clustering.clustertree ete2.clustering.clustvalidation ete2.clustering.pstat ete2.clustering.stats ete2.coretype ete2.coretype.arraytable ete2.coretype.seqgroup ete2.coretype.tree ete2.parser ete2.parser.fasta ete2.parser.newick ete2.parser.phylip ete2.parser.text_arraytable ete2.phylo ete2.phylo.evolevents ete2.phylo.phylotree ete2.phylo.reconciliation ete2.phylo.spoverlap ete2.phylomedb ete2.phylomedb.phylomeDB ete2.treeview ete2.treeview._about ete2.treeview._mainwindow ete2.treeview._open_newick ete2.treeview._search_dialog ete2.treeview._show_newick ete2.treeview.drawer ete2.treeview.ete_resources_rc ete2.treeview.faces ete2.treeview.layouts

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev95``'``
| ROOTED_PHYLOMES = ``{`1`:` `{``'``Aga``'``:` 8`,` `'``Ago``'``:` 9`,` `'``Ame``'``:` 8`,` `'``Ath``'``:` 10`...``
| __package__ = ``'``ete2``'``

Variables Details | [hide private]

  ### ROOTED_PHYLOMES Value:
      {1: {'Aga': 8,
           'Ago': 9,
           'Ame': 8,
           'Ath': 10,
           'Bta': 3,
           'Cal': 9,
           'Cbr': 8,
           'Cel': 8,
      ...